Index: src/globals.h |
diff --git a/src/globals.h b/src/globals.h |
index dd49ef3b17fcf8c5d55df5ad689d887cfdeb60dc..414ff9b62dcc91c7ad0b297a530e885a55ea01d5 100644 |
--- a/src/globals.h |
+++ b/src/globals.h |
@@ -651,7 +651,7 @@ enum ScopeType { |
EVAL_SCOPE, // The top-level scope for an eval source. |
FUNCTION_SCOPE, // The top-level scope for a function. |
MODULE_SCOPE, // The scope introduced by a module literal |
- GLOBAL_SCOPE, // The top-level scope for a program or a top-level eval. |
+ SCRIPT_SCOPE, // The top-level scope for a script or a top-level eval. |
CATCH_SCOPE, // The scope introduced by catch. |
BLOCK_SCOPE, // The scope introduced by a new block. |
WITH_SCOPE, // The scope introduced by with. |